@@ -60,7 +60,7 @@ async def build_sensors(hass, LOGGER, account, CONST, debug=False):
         LOGGER=LOGGER,
         async_executor=hass.async_add_executor_job,
         balance=balance_fn,
-        account_id=account.get("account_id"),
+        account_id=account["id"],
     )
     interval = timedelta(minutes=int(account["config"][CONST["REFRESH_RATE"]]))
     balance_coordinator = build_coordinator(
@@ -75,7 +75,6 @@ async def build_sensors(hass, LOGGER, account, CONST, debug=False):
             NordigenBalanceSensor(
                 domain=CONST["DOMAIN"],
                 icons=CONST["ICON"],
-                balances=hass.data[CONST["DOMAIN"]]["client"].account.balances,
                 balance_type="interimAvailable",
                 coordinator=balance_coordinator,
                 **account,
@@ -87,7 +86,6 @@ async def build_sensors(hass, LOGGER, account, CONST, debug=False):
             NordigenBalanceSensor(
                 domain=CONST["DOMAIN"],
                 icons=CONST["ICON"],
-                balances=hass.data[CONST["DOMAIN"]]["client"].account.balances,
                 balance_type="interimBooked",
                 coordinator=balance_coordinator,
                 **account,
@@ -105,8 +103,7 @@ class NordigenBalanceSensor(CoordinatorEntity):
         domain,
         icons,
         coordinator,
-        balances,
-        account_id,
+        id,
         iban,
         bban,
         unique_ref,
@@ -123,9 +120,8 @@ class NordigenBalanceSensor(CoordinatorEntity):
         """Initialize the sensor."""
         self._icons = icons
         self._domain = domain
-        self._balances = balances
         self._balance_type = balance_type
-        self._account_id = account_id
+        self._id = id
         self._iban = iban
         self._bban = bban
         self._unique_ref = unique_ref
@@ -166,7 +162,6 @@ class NordigenBalanceSensor(CoordinatorEntity):
     @property
     def state(self):
         """Return the sensor state."""
-        print("code", self.coordinator.data[self._balance_type])
         return self.coordinator.data[self._balance_type]
 
     @property
